@@ -1,22 +1,29 @@
-## ---- include = FALSE---------------------------------------------------------
+## ----include = FALSE----------------------------------------------------------
 env_present <- slendr:::is_slendr_env_present()
 
+if (Sys.getenv("RUNNER_OS") == "Windows") {
+  bash_path <- "D:/a/_temp/msys64/usr/bin/bash.exe"
+} else {
+  bash_path <- NULL
+}
+
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>",
-  fig.width = 8,
-  fig.height = 6,
+  fig.width = 6,
+  fig.height = 5,
   dpi = 60,
-  eval = Sys.which("slim") != "" && env_present && Sys.getenv("RUNNER_OS") != "macOS"
+  eval = (Sys.which("slim") != "" || Sys.which("slim.exe") != "") && env_present,
+  engine.path = list(bash = bash_path)
 )
 
-nonspatial_slim <- tempfile()
-nonspatial_trees_file <- tempfile()
+nonspatial_slim <- normalizePath(tempfile(), winslash = "/", mustWork = FALSE)
+nonspatial_trees_file <-normalizePath(tempfile(), winslash = "/", mustWork = FALSE)
 
-spatial_slim <- tempfile()
-spatial_trees_file <- tempfile()
+spatial_slim <- normalizePath(tempfile(), winslash = "/", mustWork = FALSE)
+spatial_trees_file <- normalizePath(tempfile(), winslash = "/", mustWork = FALSE)
 
-msprime_trees_file <- tempfile()
+msprime_trees_file <- normalizePath(tempfile(), winslash = "/", mustWork = FALSE)
 
 Sys.setenv(NONSPATIAL_SLIM = nonspatial_slim)
 Sys.setenv(NONSPATIAL_TREES = nonspatial_trees_file)
@@ -26,7 +33,7 @@ Sys.setenv(SPATIAL_TREES = spatial_trees_file)
 
 Sys.setenv(MSPRIME_TREES = msprime_trees_file)
 
-## ---- message = FALSE---------------------------------------------------------
+## ----message = FALSE----------------------------------------------------------
 library(slendr)
 
 library(dplyr)
@@ -62,7 +69,7 @@ ts_small <- ts_simplify(ts, simplify_to = samples)
 tree <- ts_phylo(ts_small, 42 - 1)
 tree
 
-## ---- nonslendr_tree, eval = Sys.which("slim") != "" && env_present && Sys.getenv("RUNNER_OS") != "macOS" && Sys.getenv("R_HAS_GGTREE") == TRUE----
+## ----nonslendr_tree, eval = (Sys.which("slim") != "" || Sys.which("slim.exe") != "") && env_present && Sys.getenv("R_HAS_GGTREE") == TRUE----
 #  library(ggtree)
 #  
 #  labels <- ts_nodes(tree) %>% select(node = phylo_id, tskit_id = node_id)
@@ -70,13 +77,13 @@ tree
 #  ggtree(tree, branch.length = "none") %<+% labels +
 #    geom_label(aes(label = tskit_id))
 
-## ---- eval = Sys.which("slim") != "" && env_present && Sys.getenv("RUNNER_OS") != "macOS" && Sys.getenv("R_HAS_GGTREE") != TRUE----
+## ----eval = (Sys.which("slim") != "" || Sys.which("slim.exe") != "") && env_present && Sys.getenv("R_HAS_GGTREE") != TRUE----
 library(ape)
 plot(tree, show.tip.label = FALSE)
 nodelabels()
 tiplabels()
 
-## ---- include = FALSE---------------------------------------------------------
+## ----include = FALSE----------------------------------------------------------
 reticulate::py_run_string(sprintf("import msprime; msprime.simulate(100).dump('%s')", msprime_trees_file))
 
 ## -----------------------------------------------------------------------------
@@ -91,10 +98,10 @@ ts <- ts_load(spatial_trees_file) %>% ts_simplify()
 data <- ts_nodes(ts)
 data
 
-## ---- nonslendr_locations-----------------------------------------------------
+## ----nonslendr_locations------------------------------------------------------
 ggplot() + geom_sf(data = data, aes(color = time), alpha = 0.5)
 
-## ---- nonslendr_ancestries----------------------------------------------------
+## ----nonslendr_ancestries-----------------------------------------------------
 ancestral_links <- ts_ancestors(ts, 0)
 
 ggplot() +
