@@ -20,7 +20,7 @@ import pandas
 import numpy
 import math
 
-VERSION = "slendr_0.7.0"
+VERSION = "slendr_0.8.1.9000"
 
 
 def simulate(
@@ -56,11 +56,12 @@ def simulate(
       # parent population)
       if pop.parent != "__pop_is_ancestor":
           demography.add_population_split(
-              time=length - pop.tsplit_gen,
+              time=length - pop.tsplit_gen + 1,
               derived=[pop.pop],
               ancestral=pop.parent
           )
 
+
   if len(samples) == 0:
       logging.info("No sampling schedule given, generating one automatically")
       samples = pandas.DataFrame(
@@ -110,6 +111,8 @@ def simulate(
 
   logging.info("Setting up gene flow events")
 
+  census_times = []
+
   # schedule gene flow events
   for event in geneflows.itertuples():
       tstart = length - event.tend_gen + 1
@@ -127,6 +130,18 @@ def simulate(
           source=event.to,
           dest=event._1,
       )
+      # collect all census times first, then schedule census events later
+      census_times.append(tend)
+
+  # schedule individual census events
+  # TODO: for some reason msprime crashes when demography.add_census() is called
+  # multiple times for the same time, so I moved the following outside of the for
+  # loop above and schedule the census events at set(census_times) (which removes
+  # duplicate times)
+  for t in set(census_times):
+    # add a corresponding census event following this:
+    # https://tspop.readthedocs.io/en/latest/simulationsetup.html
+    demography.add_census(time=t)
 
   # make sure all slendr events are sorted by time of occurence
   # (otherwise msprime complains)
@@ -156,7 +171,7 @@ def simulate(
   # compile a set of slendr metadata to be stored in the tree sequence
   slendr_metadata = {
       "slendr": {
-          "version": "slendr_0.7.0",
+          "version": "slendr_0.8.1.9000",
           "backend": "msprime",
           "description": description,
           "sampling": {
